
# Type: genomic sequence localization_subject




URI: [biolink:genomic_sequence_localization_subject](https://w3id.org/biolink/vocab/genomic_sequence_localization_subject)


## Domain and Range

[GenomicSequenceLocalization](GenomicSequenceLocalization.md) ->  <sub>REQ</sub> [GenomicEntity](GenomicEntity.md)

## Parents

 *  is_a: [subject](subject.md)

## Children


## Used by

 * [GenomicSequenceLocalization](GenomicSequenceLocalization.md)
